@@ -1,6 +1,11 @@
 library("matrixStats")
 
-rowQuantiles_R <- function(x, probs, na.rm = FALSE, drop = TRUE, ...) {
+## Create isFALSE() if running on an old version of R
+if (!exists("isFALSE", mode="function")) {
+  isFALSE <- function(x) is.logical(x) && length(x) == 1L && !is.na(x) && !x
+}
+
+rowQuantiles_R <- function(x, probs, na.rm = FALSE, drop = TRUE, ..., useNames = NA) {
   q <- apply(x, MARGIN = 1L, FUN = function(x, probs, na.rm) {
     if (!na.rm && any(is.na(x))) {
       na_value <- NA_real_
@@ -17,6 +22,8 @@ rowQuantiles_R <- function(x, probs, na.rm = FALSE, drop = TRUE, ...) {
 
   digits <- max(2L, getOption("digits"))
   colnames(q) <- sprintf("%.*g%%", digits, 100 * probs)
+  rownames(q) <- rownames(x)
+  if (isFALSE(useNames)) rownames(q) <- NULL
 
   if (drop) q <- drop(q)
   q
@@ -28,16 +35,27 @@ rowQuantiles_R <- function(x, probs, na.rm = FALSE, drop = TRUE, ...) {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 source("utils/validateIndicesFramework.R")
 x <- matrix(runif(6 * 6, min = -6, max = 6), nrow = 6, ncol = 6)
+dimnames <- lapply(dim(x), FUN = function(n) letters[seq_len(n)])
 probs <- c(0, 0.25, 0.75, 1)
-for (rows in index_cases) {
-  for (cols in index_cases) {
-    for (na.rm in c(TRUE, FALSE)) {
+# Test with and without dimnames on x
+for (setDimnames in c(TRUE, FALSE)) {
+  if (setDimnames) dimnames(x) <- dimnames
+  else dimnames(x) <- NULL
+  
+  count <- 0L
+  for (rows in index_cases) {
+    for (cols in index_cases) {
+      count <- count + 1L
+      na.rm <- c(TRUE, FALSE)[count %% 2 + 1]
+      useNames <- c(NA, TRUE, FALSE)[count %% 3 + 1]
+
       validateIndicesTestMatrix(x, rows, cols,
                                 ftest = rowQuantiles, fsure = rowQuantiles_R,
-                                probs = probs, na.rm = na.rm, drop = FALSE)
+                                probs = probs, na.rm = na.rm, drop = FALSE, useNames = useNames)
       validateIndicesTestMatrix(x, rows, cols,
                                 fcoltest = colQuantiles, fsure = rowQuantiles_R,
-                                probs = probs, na.rm = na.rm, drop = FALSE)
+                                probs = probs, na.rm = na.rm, drop = FALSE, useNames = useNames)
     }
   }
 }
+
